==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/PluginExecution.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Plugin execution definition.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.825Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.PluginExecution")
@software.amazon.jsii.Jsii.Proxy(PluginExecution.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PluginExecution extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Which Maven goals this plugin should be associated with.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getGoals();

    /**
     * (experimental) The ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getId();

    /**
     * @return a {@link Builder} of {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PluginExecution> {
        java.util.List<java.lang.String> goals;
        java.lang.String id;

        /**
         * Sets the value of {@link PluginExecution#getGoals}
         * @param goals Which Maven goals this plugin should be associated with. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder goals(java.util.List<java.lang.String> goals) {
            this.goals = goals;
            return this;
        }

        /**
         * Sets the value of {@link PluginExecution#getId}
         * @param id The ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder id(java.lang.String id) {
            this.id = id;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PluginExecution}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PluginExecution build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PluginExecution {
        private final java.util.List<java.lang.String> goals;
        private final java.lang.String id;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.goals = software.amazon.jsii.Kernel.get(this, "goals", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.id = software.amazon.jsii.Kernel.get(this, "id", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.goals = java.util.Objects.requireNonNull(builder.goals, "goals is required");
            this.id = java.util.Objects.requireNonNull(builder.id, "id is required");
        }

        @Override
        public final java.util.List<java.lang.String> getGoals() {
            return this.goals;
        }

        @Override
        public final java.lang.String getId() {
            return this.id;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("goals", om.valueToTree(this.getGoals()));
            data.set("id", om.valueToTree(this.getId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.java.PluginExecution"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PluginExecution.Jsii$Proxy that = (PluginExecution.Jsii$Proxy) o;

            if (!goals.equals(that.goals)) return false;
            return this.id.equals(that.id);
        }

        @Override
        public final int hashCode() {
            int result = this.goals.hashCode();
            result = 31 * result + (this.id.hashCode());
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/PluginExecution.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Plugin execution definition.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.492Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.PluginExecution")
@software.amazon.jsii.Jsii.Proxy(PluginExecution.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PluginExecution extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Which Maven goals this plugin should be associated with.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getGoals();

    /**
     * (experimental) The ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getId();

    /**
     * (experimental) The phase in which the plugin should execute.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getPhase() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PluginExecution> {
        java.util.List<java.lang.String> goals;
        java.lang.String id;
        java.lang.String phase;

        /**
         * Sets the value of {@link PluginExecution#getGoals}
         * @param goals Which Maven goals this plugin should be associated with. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder goals(java.util.List<java.lang.String> goals) {
            this.goals = goals;
            return this;
        }

        /**
         * Sets the value of {@link PluginExecution#getId}
         * @param id The ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder id(java.lang.String id) {
            this.id = id;
            return this;
        }

        /**
         * Sets the value of {@link PluginExecution#getPhase}
         * @param phase The phase in which the plugin should execute.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder phase(java.lang.String phase) {
            this.phase = phase;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PluginExecution}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PluginExecution build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PluginExecution}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PluginExecution {
        private final java.util.List<java.lang.String> goals;
        private final java.lang.String id;
        private final java.lang.String phase;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.goals = software.amazon.jsii.Kernel.get(this, "goals", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.id = software.amazon.jsii.Kernel.get(this, "id", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.phase = software.amazon.jsii.Kernel.get(this, "phase", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.goals = java.util.Objects.requireNonNull(builder.goals, "goals is required");
            this.id = java.util.Objects.requireNonNull(builder.id, "id is required");
            this.phase = builder.phase;
        }

        @Override
        public final java.util.List<java.lang.String> getGoals() {
            return this.goals;
        }

        @Override
        public final java.lang.String getId() {
            return this.id;
        }

        @Override
        public final java.lang.String getPhase() {
            return this.phase;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("goals", om.valueToTree(this.getGoals()));
            data.set("id", om.valueToTree(this.getId()));
            if (this.getPhase() != null) {
                data.set("phase", om.valueToTree(this.getPhase()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.java.PluginExecution"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PluginExecution.Jsii$Proxy that = (PluginExecution.Jsii$Proxy) o;

            if (!goals.equals(that.goals)) return false;
            if (!id.equals(that.id)) return false;
            return this.phase != null ? this.phase.equals(that.phase) : that.phase == null;
        }

        @Override
        public final int hashCode() {
            int result = this.goals.hashCode();
            result = 31 * result + (this.id.hashCode());
            result = 31 * result + (this.phase != null ? this.phase.hashCode() : 0);
            return result;
        }
    }
}
